### Name: snowfall-init
### Title: Initialisation of cluster usage
### Aliases: sfInit sfStop sfParallel sfCpus sfNodes sfType sfSocketHosts
###   sfGetCluster sfSession sfSetMaxCPUs
### Keywords: package

### ** Examples

## Not run: 
##D   # Run program in plain sequential mode.
##D   sfInit( parallel=FALSE )
##D   stopifnot( sfParallel() == FALSE )
##D   sfStop()
##D 
##D   # Run in parallel mode overwriting probably given values on
##D   # commandline.
##D   # Executes via Socket-cluster with 4 worker processes on
##D   # localhost.
##D   # This is probably the best way to use parallel computing
##D   # on a single machine, like a notebook, if you are not
##D   # using sfCluster.
##D   # Uses Socketcluster (Default) - which can also be stated
##D   # using type="SOCK".
##D   sfInit( parallel=TRUE, nodes=4 )
##D   stopifnot( sfCpus() == 4 )
##D   stopifnot( sfParallel() == TRUE )
##D   sfStop()
##D 
##D   # Run parallel mode (socket) with 4 workers on 3 specific machines.
##D   sfInit( parallel=TRUE, nodes=4, type="SOCK",
##D           socketHosts=c( "biom7", "biom7", "biom11", "biom12" ) )
##D   stopifnot( sfCpus() == 4 )
##D   stopifnot( sfParallel() == TRUE )
##D   sfStop()
##D 
##D   # Hook into MPI cluster.
##D   # Note: you can use any kind MPI cluster Rmpi supports.
##D   sfInit( parallel=TRUE, nodes=4, type="MPI" )
##D   sfStop()
##D 
##D   # Hook into PVM cluster.
##D   sfInit( parallel=TRUE, nodes=4, type="PVM" )
##D   sfStop()
##D 
##D   # Run in sfCluster-mode: settings are taken from commandline:
##D   # Runmode (sequential or parallel), amount of nodes and hosts which
##D   # are used.
##D   sfInit()
##D 
##D   # Session-ID from sfCluster (or XXXXXXXX as default)
##D   session <- sfSession()
##D 
##D   # Calling a snow function: cluster handler needed.
##D   parLapply( sfGetCluster(), 1:10, exp )
##D 
##D   # Same using snowfall wrapper, no handler needed.
##D   sfLapply( 1:10, exp )
##D 
##D   sfStop()
## End(Not run)



